@@ -52,12 +52,12 @@ logfile_name = "/var/log/expire-sessions/expire-sessions.log"
 logfile = None
 pidfile = "/var/run/expire-sessions.pid"
 
-if os.path.exists("/usr/lib/mw/bin/maxwell"):
+if os.path.exists("/usr/bin/maxwell"):
+  mwprog = "/usr/bin/maxwell"
+elif os.path.exists("/usr/lib/mw/bin/maxwell"):
   mwprog = "/usr/lib/mw/bin/maxwell"
 elif os.path.exists("/usr/lib/hubzero/bin/maxwell"):
   mwprog = "/usr/lib/hubzero/bin/maxwell"
-elif os.path.exists("/usr/bin/maxwell"):
-  mwprog = "/usr/bin/maxwell"
 else:
   mwprog = ""
 
